div.phileo {
    float: right;
    height: 24px;
}
a.phileo {
    color: #AAA;
    font-size: 30px;
    text-decoration: none;
    height: 24px;
    float: left;
}
a.phileo:hover {
    color: #7DE692;
    text-decoration: none;
}
a.phileo-liked {
    color: #20A93B;
    text-decoration: none;
}
span.phileo-count {
    font-size: 20px;
    font-weight: bold;
    height: 24px;
}